#include <stdio.h>
#include <string.h>
#include "wave.h"

int read_header (FILE *f, waveheaderstruct *header)
{
	fseek (f, 0, SEEK_SET);
	return fread (header, 1, sizeof (waveheaderstruct), f);
}

int read_frames (FILE *f, int start, int length, char *data)
{
	int realstart = start;
	int reallength = length;
	int offset = 0;
	waveheaderstruct header;
	
	read_header (f, &header);
	
	if (start + length < 0 || start > (int)(header.data_length / header.byte_p_spl)) {
		memset (data, 0, length * header.byte_p_spl);
		return 0;
	}
		
	if (start < 0) {
		offset = -start;
		memset (data, 0, offset * header.byte_p_spl);
		realstart = 0;
		reallength += start;
	}
	
	if (start + length > (int)(header.data_length / header.byte_p_spl)) {
		reallength -= start + length - (header.data_length / header.byte_p_spl);
		memset (data, 0, reallength * header.byte_p_spl);
	}
	
	fseek (f, sizeof (waveheaderstruct) + ((realstart + offset) * header.byte_p_spl), SEEK_SET);

	fread (data + offset * header.byte_p_spl, header.byte_p_spl, reallength, f);

	if (ferror (f)) {
		clearerr (f);
		rewind (f);
	}
	
	return 1;
}

void print_header (FILE *f)
{
	waveheaderstruct header;
	
	read_header (f, &header);
	
	printf ("Length: %lu\n", header.length);
	printf ("Length Chunk: %lu\n", header.length_chunk);
	printf ("Format: %u\n", header.format);
	printf ("Modus: %u\n", header.modus);
	printf ("Sample Frequency: %lu\n", header.sample_fq);
	printf ("Bytes per Second: %lu\n", header.byte_p_sec);
	printf ("Bytes per Sample: %u\n", header.byte_p_spl);
	printf ("Data Length: %lu\n", header.data_length);
}
